@@ -3,6 +3,7 @@ module Test.Hspec.FailureReportSpec (main, spec) where
 import           Helper
 
 import           System.IO
+import qualified Control.Exception as E
 import           Test.Hspec.FailureReport
 
 main :: IO ()
@@ -12,5 +13,5 @@ spec :: Spec
 spec = do
   describe "writeFailureReport" $ do
     it "prints a warning on unexpected exceptions" $ do
-      r <- hCapture_ [stderr] $ writeFailureReport (error "some error")
+      r <- hCapture_ [stderr] $ writeFailureReport (E.throw (E.ErrorCall "some error"))
       r `shouldBe` "WARNING: Could not write environment variable HSPEC_FAILURES (some error)\n"
